@@ -24,8 +24,7 @@
   Volker Krause \<vkrause@kde.org\>
 */
 
-#ifndef __KMIME_HEADERS_H__
-#define __KMIME_HEADERS_H__
+#pragma once
 
 #include "kmime_export.h"
 #include "kmime_header_parsing.h"
@@ -33,7 +32,6 @@
 #include <QString>
 #include <QStringList>
 #include <QDateTime>
-#include <QMap>
 #include <QVector>
 #include <QByteArray>
 #include <QMetaType>
@@ -82,7 +80,7 @@ enum contentDisposition {
 #define kmime_mk_trivial_ctor( subclass )                               \
     public:                                                               \
     subclass();                           \
-    ~subclass();
+    ~subclass() override;
 
 #define kmime_mk_dptr_ctor( subclass ) \
     protected: \
@@ -232,7 +230,7 @@ class KMIME_EXPORT Unstructured : public Base
     //@endcond
 public:
     Unstructured();
-    ~Unstructured();
+    ~Unstructured() override;
 
     using Base::from7BitString;
     void from7BitString(const QByteArray &s) override;
@@ -285,7 +283,7 @@ class KMIME_EXPORT Structured : public Base
 {
 public:
     Structured();
-    ~Structured();
+    ~Structured() override;
 
     void from7BitString(const char *s, size_t len) override;
     void from7BitString(const QByteArray &s) override;
@@ -321,7 +319,7 @@ class KMIME_EXPORT Address : public Structured
 {
 public:
     Address();
-    ~Address();
+    ~Address() override;
 protected:
     //@cond PRIVATE
     kmime_mk_dptr_ctor(Address)
@@ -1198,7 +1196,7 @@ class KMIME_EXPORT Generic : public Generics::Unstructured
 public:
     Generic();
     Generic(const char *t, int len = -1);
-    ~Generic();
+    ~Generic() override;
 
     void clear() override;
 
@@ -1448,4 +1446,3 @@ Q_DECLARE_METATYPE(KMime::Headers::To*)
 Q_DECLARE_METATYPE(KMime::Headers::Cc*)
 Q_DECLARE_METATYPE(KMime::Headers::Bcc*)
 
-#endif // __KMIME_HEADERS_H__
